==> esmerald-2.0.3-py3-none-any.whl: esmerald/middleware/errors.py <==
import traceback
from typing import TypeVar

from starlette.middleware.errors import ServerErrorMiddleware as StarletteServerErrorMiddleware
from starlette.requests import Request as StarletteRequest
from starlette.responses import HTMLResponse, PlainTextResponse, Response

from esmerald.requests import Request as _Request

Request = TypeVar("Request", _Request, StarletteRequest)


class ServerErrorMiddleware(StarletteServerErrorMiddleware):
    """
    Handles returning 500 responses when a server error occurs.

    If 'debug' is set, then traceback responses will be returned,
    otherwise the designated 'handler' will be called.

    This middleware class should generally be used to wrap *everything*
    else up, so that unhandled exceptions anywhere in the stack
    always result in an appropriate 500 response.
    """

    def generate_plain_text(self, exc: Exception) -> str:
        return "".join(traceback.format_exception(type(exc), exc, exc.__traceback__))

    def debug_response(self, request: Request, exc: Exception) -> Response:
        accept = request.headers.get("accept", "")

        if "text/html" in accept:
            content = self.generate_html(exc)
            return HTMLResponse(content, status_code=500)
        content = self.generate_plain_text(exc)
        return PlainTextResponse(content, status_code=500)

    def error_response(self, request: Request, exc: Exception) -> Response:
        return PlainTextResponse("Internal Server Error", status_code=500)

==> esmerald-2.4.2-py3-none-any.whl: esmerald/middleware/errors.py <==
import traceback
from typing import TypeVar

from starlette.middleware.errors import ServerErrorMiddleware as StarletteServerErrorMiddleware
from starlette.requests import Request as StarletteRequest
from starlette.responses import HTMLResponse, PlainTextResponse, Response

from esmerald.requests import Request as _Request

Request = TypeVar("Request", _Request, StarletteRequest)


class ServerErrorMiddleware(StarletteServerErrorMiddleware):  # pragma: no cover
    """
    Handles returning 500 responses when a server error occurs.

    If 'debug' is set, then traceback responses will be returned,
    otherwise the designated 'handler' will be called.

    This middleware class should generally be used to wrap *everything*
    else up, so that unhandled exceptions anywhere in the stack
    always result in an appropriate 500 response.
    """

    def generate_plain_text(self, exc: Exception) -> str:
        return "".join(traceback.format_exception(type(exc), exc, exc.__traceback__))

    def debug_response(self, request: Request, exc: Exception) -> Response:
        accept = request.headers.get("accept", "")

        if "text/html" in accept:
            content = self.generate_html(exc)
            return HTMLResponse(content, status_code=500)
        content = self.generate_plain_text(exc)
        return PlainTextResponse(content, status_code=500)

    def error_response(self, request: Request, exc: Exception) -> Response:
        return PlainTextResponse("Internal Server Error", status_code=500)
